#!/usr/bin/perl -w

## Author <julien@vaubourg.com>
## Sonde intermediaire pour le reformatage des donnees de metrologie de differents checks
## pour Centreon

use strict;
use warnings;
use POSIX qw(strftime);

# Recuperation des arguments
my $check = shift;
my $host = shift;
my ($pluginsPath) = $0 =~ /(.*)\/.*/;

# Lancement du vrai check par NRPE
my $values = `$pluginsPath/check_nrpe -H $host -c $check -a @ARGV 2>&1`;
my $return = $?;

# Checks de mesure de valeur relative a une autre
# => donc trois valeurs : total, free, used
if($check =~ /_(disk|swap|mem)_/) {
	my ($status, $disk, $used, $w, $c, $total);

	# Check de disque dur
	if($check =~ /_disk_/) {
		if($values =~ /^(.*)\|\s*([^=]+)=(\d+)MB;(\d+);(\d+);(\d+);(\d+)/) {
			$status = $1;
			$disk = $2;
			$used = $3 * 1024*1024;
			$w = ($4 - $4/100*5) * 1024*1024; # 5% root et passage en octets
			$c = ($5 - $5/100*5) * 1024*1024;
			$total = ($7 - $7/100*5) * 1024*1024;

			$status =~ s/- free/(PARTITION MERE) - free/ if $ARGV[0] ne $disk;
		} else {
			print $values;
		}

	# Check de swap
	} elsif($check =~ /_swap_/) {
		if($values =~ /^(.*)\|\s*swap=(\d+)MB;(\d+);(\d+);(\d+);(\d+)/) {
			$status = $1;
			$total = $6 * 1024*1024;

			$used = $total - ($2 * 1024*1024);
			$w = $total - ($3 * 1024*1024);
			$c = $total - ($4 * 1024*1024);
		} else {
			print $values;
		}

	# Check de RAM
	} elsif($check =~ /_mem_/) {
		if($values =~ /^(.*)\|\s*(\d+);(\d+);(\d+);(\d+)/) {
			$status = $1;
			$total = $2;
			$used = $total - $3;
			$w = $total - $total/100*$4;
			$c = $total - $total/100*$5;
		} else {
			print $values;
		}
	}

	print "$status| 0-Free=$total; 1-Used=$used; 2-Warning=$w; 3-Critical=$c\n";

# Check salles de Benoit
} elsif($check =~ /_salles/) {

	# Format initial : <status | nbUSERWin;nbUSERLin;nbOK;nb;tauxWarning;tauxCritical\n>
	if($values =~ /^(.*)\|\s*(\d+);(\d+);(\d+);(\d+);(\d+);(\d+)/) {
		my $nbUsers = $2 + $3;
		print "$1| 2-Salle_Utilisateurs=$nbUsers; 4-Salle_UtilisateursWindows=$2; 3-Salle_UtilisateursLinux=$3; 1-Salle_MachinesAllumees=$4; 0-Salle_Machines=$5; seuilWarning=$6; seuilCritical=$7";
	} else {
		print $values;
	}
}


exit 0 if $return == 0;
exit 1 if $return == 256;
exit 2;
