#!/bin/bash
# Author <julien@vaubourg.com> 2010

# Copier massivement des fichiers sur un lot de machines
# myPuppet.sh -h pour plus de renseignements

help() {
        echo -e "\n\tCopier un fichier sur une liste de machines distances via scp."

        echo -e "\n\tOPTIONS OBLIGATOIRES"
        echo -e "\t\t-m <file> : Liste des machines concernees (une machine par ligne)"
        echo -e "\t\t-f <file> : Fichier source"
        echo -e "\t\t-t <path> : Chemin de destination"

        echo -e "\n\tOPTIONS"
        echo -e "\t\t-h        : Afficher cette aide"

        echo -e "\n\tEXEMPLE"
        echo -e "\t\t./myPuppet.sh -m machines.lst -f fichiers/nrpe -t /etc/xinetd.d/"
}

while getopts m:f:t:h option
do
        case $option in
                m)
			machinesFile=$OPTARG
                ;;

		f)
			fileFrom=$OPTARG
		;;

		t)
			pathTo=$OPTARG
		;;

		h)
			help
			exit 0
		;;

		*)
			help
			exit 1
	esac
done

if [ -z "$machinesFile" -o -z "$fileFrom" -o -z "$pathTo" ]; then
	echo "ERREUR: Toutes les options sont obligatoires." >&2
	help
	exit 1
fi

if [ ! -r $machinesFile -o ! -r $fileFrom ]; then
	echo "ERREUR: Un des deux fichiers (machines ou fichier a envoyer) n'existe pas ou ne peut etre lu." >&2
	exit 1
fi

echo -n "Copier le fichier distant sur la machine distante en .old, si il existe (Y/n) ? "
read copy

file=${fileFrom##*/}

while read machine; do
	echo "Copie de $file dans $machine:$pathTo..."

	if [ "$copy" = "y" -o "$copy" = "Y" -o -z "$copy" ]; then
		ssh root@$machine "cp $pathFile/$file{,.old}"
	fi

	scp $fileFrom root@$machine:$pathTo/$file
done < $machinesFile

echo -e "\nAux toilettes puppet."
exit 0
