#!/bin/bash
# Auteur <julien@vaubourg.com> pour le CRI de INPL
# 2010 - Centreon 2.0.2

# Aide a l'importation d'une configuration Nagios existante dans un Centreon, en utilisant
# le script ruby nagios2centreon.rb.
# Le script place les definitions a copier-coller dans la rubrique Load de Centreon, directement dans le presse-papier (clic milieu).
# Voir la section Procedure d'importation dans l'entete du fichier nagios2centreon.rb

# Prend en argument le dossier des .cfg a convertir et demande a creer le dossier toCentreon dans ce dossier (si le script
# n'a pas ete change).

# Depends : xclip

# Script de preparation des CFG
nagios2centreon=/home/ju/SCRIPTS/nagios2centreon.rb

if [ ! -x "$nagios2centreon" ]; then
	echo "ERREUR: nagios2centreon est introuvable ou non-executable" >&2
	exit 1
fi

# Ordre d'affichage des definitions pour une correcte importation dans Centreon
orderCfg='commands timeperiods contacts contactgroups tplHosts hosts hostdependencys hostgroups tplServices services servicegroups serviceescalations'

if [ -z "$1" -o ! -r "$1" ]; then
	echo "ERREUR: Le dossier de confs est absent ou non-consultable" >&2
	echo "Usage: $0 dossier_de_confs/" >&2
	exit 1
fi

cd $1

# Creation du repertoire toCentreon et conversion des fichiers .cfg
$nagios2centreon *.cfg
cd toCentreon

# Remplacement des emails de contact (periodes de tests)
sed -i 's/email .*/email julien.vaubourg@inpl-nancy.fr/' contacts.cfg

# Copie des commandes de notification dans le presse-papier
cat notifyCommands.cfg | xclip
nbDefine=$(grep -c '^define ' notifyCommands.cfg)

echo -e "\n$nbDefine commandes de notification dans le presse-papier."
echo "Appuyer sur Entree pour continuer (penser a vider le <Manual Filling> avant de continuer)."
read ok

# Affichage du nombre de definitions pour chaque fichier
for i in $orderCfg; do
	if [ -f $i.cfg ]; then
		nbDefine=$(grep -c '^define ' $i.cfg)
		echo $nbDefine $i
	fi
done

# Copie le reste de la configuration dans le presse-papier
for i in $orderCfg; do
	[ -f $i.cfg ] && cat $i.cfg;
done | xclip

echo -e "\nCommandes de checks et autres definitions dans le presse-papier."
echo "Appuyer sur Entree pour quitter."
read ok
