#!/usr/bin/perl -w
# Auteur <julien@vaubourg.com> pour le CRI de INPL
# 2010 - Centreon 2.0.2

# Remplace les noms d'hosts par leur nom DNS, parfois abrege

use strict;
use warnings;
use DBI;

my $mysql = DBI->connect('DBI:mysql:database=centreon2;host=localhost', 'tmp', 'tmp', { 'RaiseError' => 1 });

# Selection de tous les hosts qui ne sont pas des tpl
my $sql = $mysql->prepare("SELECT host_name name, host_address ip
				FROM host
				WHERE host_register='1'");

$sql->execute;

# Pour chaque host
while(my $h = $sql->fetchrow_hashref) {
	my $name = $h->{'name'};
	my $ip = $h->{'ip'};

	# Recuperation de tous les noms de domaine retournes par une requete DNS invers sur l'IP
	my $hostCmd = `host $ip 2> /dev/null | awk '\$NL ~ /domain name pointer/ { print substr(\$NF, 0, length(\$NF)-1) }'`;
	my @addrs = split /\n/, $hostCmd;
	my $addr = 0;

	# Pour chacune de ces adresses, on selectionne celle qui porte le nom actuel de la machine
	for (@addrs) {
		$addr = $_ if $_ =~ /^$name/i;
	}

	# Si un des DNS retournes ne porte le nom de l'host, il faut une intelligence humaine
	unless($addr) {

		# Suppression du suffixe .inpl-nancy.fr, si besoin est,
		# sinon le DNS restera complet
		if($addrs[0]) {
			$addrs[0] =~ s/\.inpl-nancy\.fr//;

		# Aucun DNS n'a ete trouve pour la machine : c'est le cas pour les sondes
		# de temperature qui n'ont pas de nom de domaine, par ex
		} else {
			$addrs[0] = '!ERREUR!';
		}

		# Tant qu'un nom n'a pas ete trouve, on propose le premier trouve
		do {
			print "\nDOUTE: Nouveau nom pour <$name> (defaut: <", $addrs[0], "> - $ip) : ";

			$addr = <>;
			chomp($addr);

			# Si un nom a ete propose, on l'enregistre
			# Sinon, cela signifie qu'on garde celui propose
			$addr = $addrs[0] if $addr eq "";
		} while($addr eq '!ERREUR!');

	# Si un des DNS contient le nom de l'host, on se contente de supprimer eventuellement
	# le suffixe INPL et on met a jour
	} else {
		$addr =~ s/\.inpl-nancy\.fr//;
	}

	# Mise a jour du nom d'host
	if($name ne $addr) {
		print "CHANGE: <$name> en <$addr>\n";
		$mysql->do("UPDATE host SET host_name=".$mysql->quote($addr)." WHERE host_name='$name'");
	} else {
		print "OK: $addr\n";
	}
}

$sql->finish;
$mysql->disconnect;
